==> lpack-3.2.4.tar.gz: lpack-3.2.4/setup.py <==
from setuptools import setup, find_packages


setup(name='lpack',
      version='3.2.4',
      description=(
          'Hello '
      ),
      long_description='For detail please step to https://github.com/robbebluecp/llpack',
      long_description_content_type="text/markdown",
      author='Robbe',
      author_email='robbebluecp@gmail.com',
      maintainer='Robbe',
      maintainer_email='robbebluecp@gmail.com',
      license='MIT License',
      packages=find_packages(),
      package_data={'': ['*.so']},
      platforms=["all"],
      url='https://github.com/robbebluecp/llpack',
      classifiers=[
          "Environment :: Web Environment",
          "Intended Audience :: Developers",
          "Operating System :: OS Independent",
          "Topic :: Text Processing :: Indexing",
          "Topic :: Utilities",
          "Topic :: Internet",
          "Topic :: Software Development :: Libraries :: Python Modules",
          "Programming Language :: Python",
          'Programming Language :: Python :: 3.7',
          'Programming Language :: Python :: 3.8',
          'Programming Language :: Python :: 3.9'
      ],
      install_requires=[
          'pymssql',
          'pymysql',
          'clickhouse_driver',
          'concurrent_log_handler',
          'pillow',
          'emoji',
          'numpy',
          'redis',
          'py2neo',
          'pymongo',
          'oss2',
          'pillow',
          'pika',
          'fastapi',
          'jinja2',
          'gevent',
          'gunicorn',
          'uvicorn',
          'greenlet',
          'watchgod',
          'httptools',
          'baidu-aip',
          'elasticsearch==8.2',
          'tronpy',
          'pyotp',
          'qrcode',
          'hdwallet',
          'kafka-python',
          'opencv-python==4.5.1.48',
          'opencv-contrib-python ==4.5.1.48',
          'cos-python-sdk-v5',
      ])

==> lpack-3.2.5.tar.gz: lpack-3.2.5/setup.py <==
from setuptools import setup, find_packages


setup(name='lpack',
      version='3.2.5',
      description=(
          'Hello '
      ),
      long_description='For detail please step to ',
      long_description_content_type="text/markdown",
      author='Robbe',
      author_email='robbebluecp@gmail.com',
      maintainer='Robbe',
      maintainer_email='robbebluecp@gmail.com',
      license='MIT License',
      packages=find_packages(),
      package_data={'': ['*.so']},
      platforms=["all"],
      url='',
      classifiers=[
          "Environment :: Web Environment",
          "Intended Audience :: Developers",
          "Operating System :: OS Independent",
          "Topic :: Text Processing :: Indexing",
          "Topic :: Utilities",
          "Topic :: Internet",
          "Topic :: Software Development :: Libraries :: Python Modules",
          "Programming Language :: Python",
          'Programming Language :: Python :: 3.7',
          'Programming Language :: Python :: 3.8',
          'Programming Language :: Python :: 3.9'
      ],
      install_requires=[
          'pymssql',
          'pymysql',
          'clickhouse_driver',
          'concurrent_log_handler',
          'pillow',
          'emoji',
          'numpy',
          'redis',
          'py2neo',
          'pymongo',
          'oss2',
          'pillow',
          'pika',
          'fastapi',
          'jinja2',
          'gevent',
          'gunicorn',
          'uvicorn',
          'greenlet',
          'watchgod',
          'httptools',
          'baidu-aip',
          'elasticsearch==8.2',
          'tronpy',
          'pyotp',
          'qrcode',
          'hdwallet',
          'kafka-python',
          'opencv-python==4.5.1.48',
          'opencv-contrib-python ==4.5.1.48',
          'cos-python-sdk-v5',
      ])
